@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Log::Dispatch::File::Stamped; # git description: v0.16-10-g18dafcc
+package Log::Dispatch::File::Stamped; # git description: v0.17-4-g56e90fc
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Logging to date/time stamped files
 # KEYWORDS: log logging output file timestamp date rolling rotate
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use File::Basename        qw(fileparse);
 use File::Spec::Functions qw(catfile);
@@ -83,7 +83,8 @@ sub log_message
     $self->_make_filename;
 
     # don't re-open if we use close-after-write - the superclass will do it
-    if (not $self->{close} and $old_filename ne $self->{filename})
+    if (not $self->{ Log::Dispatch->VERSION >= '2.59' ? 'close_after_write' : 'close' }
+            and $old_filename ne $self->{filename})
     {
         $self->_open_file;
     }
@@ -105,7 +106,7 @@ Log::Dispatch::File::Stamped - Logging to date/time stamped files
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
